pub struct Run {
pub tstart: f64,
pub tstop: f64,
pub dt: f64,
pub dl: Option<f64>,
pub spike_threshold: Option<f64>,
pub block: TimeBlock,
pub random_seed: Option<u64>,
}Expand description
How to run the simulation / Timestepping
Fields
tstart: f64Begin of simulation [ms]
tstop: f64End of simulation [ms]
dt: f64Timestep [ms]
dl: Option<f64>maximum CV length [um] If not given, models or simulators choose May be overwritten downstream
spike_threshold: Option<f64>Spiking threshold [mV] If not given, models or simulators choose May be overwritten downstream
block: TimeBlocktime blocking
random_seed: Option<u64>Seed for PRNG